def design():
    style = """

        QPushButton {
 
                text-align: center;
 				border-radius: 30px;
  				padding: 0.2em 0.2em 0.3em 0.2em;
    			border: 1px solid rgb(100, 100, 100);
    			background: rgb(255,255,255);


			}
        QPushButton:hover {
			    background-color:rgb(240, 228, 230);
			   
			}
        QPushButton:pressed {
			    background-color: rgb(217, 217, 217); 
			}
        """
    return style
